Module copy

Module copy 

COPY protocol handlers.

Traits

CopyHandler
handler for copy messages

Functions

send_copy_both_response
Send a CopyBothResponse header and stream copy data to the client.
send_copy_in_response
Send a CopyInResponse message to the client.
send_copy_out_response
Send a CopyOutResponse header and stream copy data to the client.