Struct DataRowEncoder

pub struct DataRowEncoder { /* private fields */ }

Implementations

Source

impl DataRowEncoder

pub fn new(fields: Arc<Vec<FieldInfo>>) -> DataRowEncoder

New DataRowEncoder from schema of column

pub fn encode_field_with_type_and_format<T>( &mut self, value: &T, data_type: &Type, format: FieldFormat, ) -> PgWireResult<()>
where T: ToSql + ToSqlText + Sized,

Encode value with custom type and format

This encode function ignores data type and format information from schema of this encoder.

pub fn encode_field<T>(&mut self, value: &T) -> PgWireResult<()>
where T: ToSql + ToSqlText + Sized,

Encode value using type and format, defined by schema

Panic when encoding more columns than provided as schema.

pub fn finish(self) -> PgWireResult<DataRow>