Struct DataRow

#[non_exhaustive]
pub struct DataRow { pub data: BytesMut, pub field_count: i16, }
Data structure for postgresql wire protocol DataRow message.

Data can be represented as text or binary format as specified by format codes from previous RowDescription message.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
data: BytesMutfield_count: i16

Implementations

Source

impl DataRow

pub fn new(data: BytesMut, field_count: i16) -> Self

Constructs a new DataRow.