Module startup

Module startup 

Startup messages

Structs

BackendKeyData
BackendKeyData message, sent from backend to frontend for issuing CancelRequestMessage
GssEncRequest
GssEncRequest sent from frontend to negotiate with backend to check if the backend supports GSSAPI secure connection. The packet has no message type and contains only a length(4) and an i32 value.
NegotiateProtocolVersion
Negotiate protocol version message sent from backend
ParameterStatus
parameter ack sent from backend after authentication success
Password
password packet sent from frontend
SASLInitialResponse
SASL initial response sent from frontend during authentication
SASLResponse
SASL response sent from frontend during authentication
SslRequest
Sslrequest sent from frontend to negotiate with backend to check if the backend supports secure connection. The packet has no message type and contains only a length(4) and an i32 value.
Startup
Postgresql wire protocol startup message.

Enums

Authentication
authentication response family, sent by backend
PasswordMessageFamily
In postgres wire protocol, there are several message types share the same message type ‘p’:
SecretKey
The secret key for canceling query

Constants

MESSAGE_TYPE_BYTE_AUTHENTICATION
Message type byte for Authentication
MESSAGE_TYPE_BYTE_BACKEND_KEY_DATA
Message type byte for BackendKeyData
MESSAGE_TYPE_BYTE_NEGOTIATE_PROTOCOL_VERSION
Message type byte for NegotiateProtocolVersion
MESSAGE_TYPE_BYTE_PARAMETER_STATUS
Message type byte for ParameterStatus
MESSAGE_TYPE_BYTE_PASSWORD_MESSAGE_FAMILY
Message type byte for password message family