parse_options

Function parse_options 

fn parse_options(options: &str) -> PsqlResult<Vec<(String, String)>>
Handle options in StartupMessage from client

It is like shell arguments but only respects backslash-escape and space; quotes have no special meaning and are handled literally.

PostgreSQL allows both -c key=value and --key=value.

key-name is normalized as key_name.