pub struct ExecContextGuard(Arc<ExecContext>);Expand description
ExecContextGuard holds a Arc pointer. Once ExecContextGuard is dropped,
the inner Arc<ExecContext> should not be referred anymore, so that its Weak reference (used in SessionImpl) will be the same lifecycle of the running sql execution context.
Tuple Fields
0: Arc<ExecContext>Implementations
Sourceimpl ExecContextGuard
impl ExecContextGuard
pub fn new(exec_context: Arc<ExecContext>) -> Self