Module types

Module types 

types and encoding related helper

Modules

format
PostgreSQL text format configuration and helpers.

Statics

QUOTE_CHECK
Re-export of the Rust-to-text serialization trait and quoting helpers. Regex to check if an array element needs quoting.
QUOTE_ESCAPE
Re-export of the Rust-to-text serialization trait and quoting helpers. Regex to escape special characters in quoted array elements.

Traits

FromSqlText
Re-export of the text-to-Rust parsing trait. Trait for parsing PostgreSQL text format into Rust types.
ToSqlText
Re-export of the Rust-to-text serialization trait and quoting helpers. Trait for serializing Rust types to PostgreSQL text format.