handler layer and high-level API layer. APIs for building postgresql compatible servers.
Modules
- auth
- Authentication handlers for the startup phase.
- cancel
- Cancel request handling.
- copy
- COPY protocol handlers.
- portal
- Portal management for the extended query protocol.
- query
- Simple and extended query handlers.
- results
- Query result encoding and formatting.
- stmt
- Prepared statement management.
- store
- Portal and prepared statement storage backends.
- transaction
- Transaction status tracking.
Structs
- Connection
Guard - RAII guard that unregisters a connection from the
ConnectionManageron drop. - Connection
Handle - Per-connection cancel handle.
- Connection
Manager - A registry mapping
(pid, secret_key)to per-connection cancel handles. - Default
Client - Default client implementation holding all per-connection state.
- Noop
Handler - A noop implementation for
ErrorHandler. - Random
PidSecret KeyGenerator - Session
Extensions - Per-connection typed extension store, keyed by
TypeId. - Type
- A Postgres type.
Enums
- PgWire
Connection State - States of a PostgreSQL connection lifecycle.
Constants
- DEFAULT_
NAME - Default name used when no name is provided for prepared statements or portals.
- METADATA_
APPLICATION_ NAME - Metadata key for the application name.
- METADATA_
CLIENT_ ENCODING - Metadata key for the client encoding setting.
- METADATA_
DATABASE - Metadata key for the target database name.
- METADATA_
USER - Metadata key for the connected user name.
Traits
- Client
Info - Describe a client information holder
- Client
Portal Store - Client Portal Store
- Error
Handler - A centralized handler for all errors
- PgWire
Server Handlers - A collection of all handler traits required to serve a PostgreSQL connection.
- PidSecret
KeyGenerator - Generator for process ID and secret key pairs used to identify connections for cancel requests.