COPY protocol handlers.
Traits
- Copy
Handler - handler for copy messages
Functions
- send_
copy_ both_ response - Send a CopyBothResponse header and stream copy data to the client.
- send_
copy_ in_ response - Send a CopyInResponse message to the client.
- send_
copy_ out_ response - Send a CopyOutResponse header and stream copy data to the client.