Struct Portal

#[non_exhaustive]
pub struct Portal<S> { pub name: String, pub statement: Arc<StoredStatement<S>>, pub parameter_format: Format, pub parameters: Vec<Option<Bytes>>, pub result_column_format: Format, }
Represent a prepared sql statement and its parameters bound by a Bind request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Stringstatement: Arc<StoredStatement<S>>parameter_format: Formatparameters: Vec<Option<Bytes>>result_column_format: Format

Implementations

Source

impl<S: Clone> Portal<S>

pub fn try_new( bind: &Bind, statement: Arc<StoredStatement<S>>, ) -> PgWireResult<Self>

Try to create portal from bind command and current client state

pub fn parameter_len(&self) -> usize

Get number of parameters

pub fn parameter<T>( &self, idx: usize, pg_type: &Type, ) -> PgWireResult<Option<T>>
where T: FromSqlOwned,

Attempt to get parameter at given index as type T.