pub struct DataRowEncoder { /* private fields */ }Implementations
Sourceimpl DataRowEncoder
impl DataRowEncoder
Sourcepub fn new(fields: Arc<Vec<FieldInfo>>) -> DataRowEncoder
pub fn new(fields: Arc<Vec<FieldInfo>>) -> DataRowEncoder
New DataRowEncoder from schema of column
Sourcepub fn encode_field_with_type_and_format<T>(
&mut self,
value: &T,
data_type: &Type,
format: FieldFormat,
) -> PgWireResult<()>
pub fn encode_field_with_type_and_format<T>( &mut self, value: &T, data_type: &Type, format: FieldFormat, ) -> PgWireResult<()>
Encode value with custom type and format
This encode function ignores data type and format information from schema of this encoder.
Sourcepub fn encode_field<T>(&mut self, value: &T) -> PgWireResult<()>
pub fn encode_field<T>(&mut self, value: &T) -> PgWireResult<()>
Encode value using type and format, defined by schema
Panic when encoding more columns than provided as schema.
pub fn finish(self) -> PgWireResult<DataRow>