Startup messages
Structs
- Backend
KeyData BackendKeyDatamessage, sent from backend to frontend for issuingCancelRequestMessage- GssEnc
Request GssEncRequestsent from frontend to negotiate with backend to check if the backend supports GSSAPI secure connection. The packet has no message type and contains only a length(4) and an i32 value.- Negotiate
Protocol Version - Negotiate protocol version message sent from backend
- Parameter
Status - parameter ack sent from backend after authentication success
- Password
- password packet sent from frontend
- SASL
Initial Response - SASL initial response sent from frontend during authentication
- SASL
Response - SASL response sent from frontend during authentication
- SslRequest
Sslrequestsent from frontend to negotiate with backend to check if the backend supports secure connection. The packet has no message type and contains only a length(4) and an i32 value.- Startup
- Postgresql wire protocol startup message.
Enums
- Authentication
- authentication response family, sent by backend
- Password
Message Family - In postgres wire protocol, there are several message types share the same message type ‘p’:
- Secret
Key - The secret key for canceling query
Constants
- MESSAGE_
TYPE_ BYTE_ AUTHENTICATION - Message type byte for Authentication
- MESSAGE_
TYPE_ BYTE_ BACKEND_ KEY_ DATA - Message type byte for BackendKeyData
- MESSAGE_
TYPE_ BYTE_ NEGOTIATE_ PROTOCOL_ VERSION - Message type byte for NegotiateProtocolVersion
- MESSAGE_
TYPE_ BYTE_ PARAMETER_ STATUS - Message type byte for ParameterStatus
- MESSAGE_
TYPE_ BYTE_ PASSWORD_ MESSAGE_ FAMILY - Message type byte for password message family