types and encoding related helper
Modules
- format
- PostgreSQL text format configuration and helpers.
Statics
- QUOTE_
CHECK - Re-export of the Rust-to-text serialization trait and quoting helpers. Regex to check if an array element needs quoting.
- QUOTE_
ESCAPE - Re-export of the Rust-to-text serialization trait and quoting helpers. Regex to escape special characters in quoted array elements.
Traits
- From
SqlText - Re-export of the text-to-Rust parsing trait. Trait for parsing PostgreSQL text format into Rust types.
- ToSql
Text - Re-export of the Rust-to-text serialization trait and quoting helpers. Trait for serializing Rust types to PostgreSQL text format.